/// This module contains everything everything, to convert the given JSON file into Rust structs using serde.
mod parser;

use time::{format_description, OffsetDateTime};

use crate::{law::parser::OgdSearchResult, Error};

/// Returns the current date in YYYY-MM-DD format. Needed for RIS API query to get current version of the law.
fn current_date() -> String {
    let local_date = OffsetDateTime::now_utc();
    let format = format_description::parse("[year]-[month]-[day]").unwrap(); //unwrap okay, supplied format is fine
    local_date.format(&format).expect("Failed to format date")
}

/// Fetches the json content of the given law (`law_id`) from the RIS API.
/// 
/// # Errors
/// Fails if `ureq` can't create a connection, probably because there's no internet connection? (Or RIS is not online.)
fn fetch_page(law_id: usize) -> Result<String, Error> {
    Ok(
        ureq::post("https://data.bka.gv.at/ris/api/v2.6/Bundesrecht")
            .send_form(&[
                ("Applikation", "BrKons"),
                ("Gesetzesnummer", &format!("{}", law_id)),
                ("DokumenteProSeite", "OneHundred"),
                ("Seitennummer", &format!("{}", 1)),
                ("Fassung.FassungVom", &current_date()),
            ])?
            .into_string()?,
    )
}

pub(crate) fn parse(law_id: usize) -> Result<(), Error> {
    let json = fetch_page(law_id)?;

    let ogd_search_result: OgdSearchResult = serde_json::from_str(&json)?;

    Ok(())
}
